#
# spec file for package aerc
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2023 Hannes Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aerc
Version:        0.15.2
Release:        3.1
Summary:        An email client for terminals
License:        MIT
Group:          Productivity/Networking/Email/Clients
URL:            https://aerc-mail.org/
Source:         %{name}-%{version}.tar.gz
Patch0:         fix-script-interpreter.patch
BuildRequires:  gcc
BuildRequires:  go
BuildRequires:  make
BuildRequires:  notmuch-devel
BuildRequires:  scdoc
Recommends:     dante
Recommends:     w3m

%description
aerc is an email client that runs in terminals.

%prep
%autosetup -p1

%build
%if "%{_arch}" == "ppc64"
    %make_build CC=cc GOFLAGS=""
%else
    %make_build CC=cc GOFLAGS="-buildmode=pie -tags=notmuch"
%endif

%install
%make_install PREFIX=%{_prefix} LIBEXECDIR=%{_libexecdir}/%{name}

%files
%license LICENSE
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_libexecdir}/%{name}
%{_mandir}/man1/aerc.1.gz
%{_mandir}/man1/aerc-search.1.gz
%{_mandir}/man5/aerc-accounts.5.gz
%{_mandir}/man5/aerc-binds.5.gz
%{_mandir}/man5/aerc-config.5.gz
%{_mandir}/man5/aerc-imap.5.gz
%{_mandir}/man5/aerc-maildir.5.gz
%{_mandir}/man5/aerc-sendmail.5.gz
%{_mandir}/man5/aerc-notmuch.5.gz
%{_mandir}/man5/aerc-smtp.5.gz
%{_mandir}/man7/aerc-tutorial.7.gz
%{_mandir}/man7/aerc-templates.7.gz
%{_mandir}/man7/aerc-stylesets.7.gz

%changelog
* Sun Aug  6 2023 Joshua Smith <jsmithfpv@gmail.com>
- Add dante and w3m to Recommends due to html filters.
* Thu May 11 2023 Jan Engelhardt <jengelh@inai.de>
- Trim rhetorics from descriptions.
* Thu May 11 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.2
- Update to upstream version 0.15.2
  * Extra messages disappearing when deleting on maildir.
  * "colorize" and "wrap" filters option parsing on ARM.
* Fri Apr 28 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.1
- Update to upstream version 0.15.1
  * Fix embedded terminal partial refreshes.
  * Fix maildir message updates after "mbsync".
* Thu Apr 27 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.0
- Update to upstream version 0.15.0
  * New column-based message list format with "index-columns".
  * Add a "msglist_answered" style for answered messages.
  * Compose "Format=Flowed" messages with "format-flowed=true" in aerc.conf.
  * Add a trimSignature function to the templating engine.
  * Change local domain name for SMTP with "smtp-domain=example.com" in
    aerc.conf
  * New column-based status line format with "status-columns".
  * Inline user-defined styles can be inserted in UI templates via the
    {{.Style "name" string}} function.
  * Add the ability to run arbitrary commands over the socket. This can be
    disabled using the disable-ipc setting.
  * Allow configuring URL handlers via "x-scheme-handler/<scheme> [openers]" in
    aerc.conf.
  * Allow basic shell globbing in [openers] MIME types.
  * Dynamic "msglist_*" styling based on email header values in stylesets.
  * Add "mail-received", "aerc-startup", and "aerc-shutdown" hooks.
  * Search/filter by flags with the "-H" flag.
  * The built-in colorize filter theme is now configured in styleset files into
    the [viewer] section.
  * The standard Usenet signature delimiter "-- " is now prepended to
    "signature-file" and "signature-cmd" if not already present.
  * All aerc(1) commands now interpret aerc-templates(7) markup.
  * running commands (like mailto: or mbox:) no longer prints a success message
  * The built-in colorize filter now emits OSC 8 to mark URLs and emails. Set
    "[general].enable-osc8 = true" in aerc.conf to enable it.
  * [ui].index-format setting has been replaced by index-columns.
  * [statusline].render-format has been replaced by status-columns.
  * Removed support for [ui:subject...] contextual sections in aerc.conf.
  * [triggers] setting has been replaced by [hooks].
  * smtp-starttls setting in accounts.conf has been removed. All smtp://
    transports now assume STARTTLS and will fail if the server does not support
    it. To disable STARTTLS, use smtp+insecure://.
- Remove "filters-install-location.patch: merged into upstream
- Remove "fix-english-typos.patch": merged into upstream
* Sun Mar 26 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Fix ppc64 build
* Wed Mar  8 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Add group tag
- Add support for systems without a libexec directory
* Tue Jan 31 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Initial package creation with version 0.14.0
  * View common email envelope headers with ":envelope".
  * Notmuch accounts now support maildir operations: ":copy", ":move", ":mkdir",
    ":rmdir", ":archive" and the "copy-to" option.
  * Display messages from bottom to top with [ui].reverse-msglist-order=true in
    aerc.conf.
  * Display threads from bottom to top with [ui].reverse-thread-order=true in
    aerc.conf.
  * Style search results in the message list with msglist_result.*.
  * Preview messages with their attachments before sending with ":preview".
  * Filter commands now have AERC_FORMAT, AERC_SUBJECT and AERC_FROM
    defined in their environment.
  * Override the subject prefix for replies pattern with subject-re-pattern in
    accounts.conf.
  * Search/filter by absolute and relative date ranges with the "-d" flag.
  * LIST-STATUS and ORDEREDSUBJECT threading extensions support for imap.
  * Built-in wrap filter that does not mess up nested quotes and lists.
  * Write multipart/alternative messages with ":multipart" and commands defined
    in the new [multipart-converters] section of aerc.conf.
  * Close the message viewer before opening the composer with ":reply -c".
  * Attachment indicator in message list flags (by default a, but can be
    changed via [ui].icon-attachment in aerc.conf).
  * Open file picker menu with ":attach -m". The menu must be generated by an
    external command configured via [compose].file-picker-cmd in aerc.conf.
  * Sample stylesets are now installed in $PREFIX/share/aerc/stylesets.
  * The built-in colorize filter now has different themes.
  * pgp-provider now defaults to auto. It will use the system gpg unless
    the internal keyring exists and contains at least one key.
  * Calling ":split" or ":vsplit" without specifying a size, now attempts to use
    the terminal size to determine a useful split-size.
  * ":pipe -m git am -3" on patch series when Message-Id headers have not been
    generated by "git send-email".
  * Overflowing text in header editors while composing can now be scrolled
    horizontally.
  * Removed broken ":set" command.
